@@ -341,7 +341,11 @@ flexsurv.splineinits <- function(t=NULL, mf, mml, aux)
     dXq <- dXq[is.finite(logH),,drop=FALSE]
     eps <- rep(1e-09, length(y)) # so spline is strictly increasing
 
-    inits <- solve.QP(Dmat=t(Xq) %*% Xq, dvec=t(t(y) %*% Xq), Amat=t(dXq), bvec=eps)$solution
+    Dmat <- t(Xq) %*% Xq
+    posdef <- all(eigen(Dmat)$values > 0) # TODO work out why non-positive definite matrices can occur here
+    if (!posdef)
+        inits <- flexsurv.splineinits.cox(t=t, mf=mf, mml=mml, aux=aux)
+    else inits <- solve.QP(Dmat=Dmat, dvec=t(t(y) %*% Xq), Amat=t(dXq), bvec=eps)$solution
     inits
 }
 
@@ -458,7 +462,7 @@ flexsurvspline <- function(formula, data, weights, bhazard, subset,
     args$weights <- temp$weights
     args$bhazard <- temp$bhazard
     args$subset <- temp$subset
-    
+
     ret <- do.call("flexsurvreg", args) # faff to make ... args work within functions
     ret <- c(ret, list(k=length(knots) - 2, knots=knots, scale=scale))
     ret$call <- call
